cangaroo/excansock

Internal bindings to the Excansock Elixir library.

This module provides direct FFI bindings to the Excansock Elixir module, which handles the lower-level SocketCAN operations. These functions are used internally by the main cangaroo module and are not part of the public API.

Values

pub fn close(pid: process.Pid) -> atom.Atom
pub fn open(
  pid: process.Pid,
  interface: String,
  canfd: Bool,
) -> dynamic.Dynamic
pub fn recv_own_messages(
  pid: process.Pid,
  value: Bool,
) -> atom.Atom
pub fn send(
  pid: process.Pid,
  frame: dynamic.Dynamic,
) -> atom.Atom
pub fn set_error_filter(
  pid: process.Pid,
  filter: Int,
) -> atom.Atom
pub fn set_filters(
  pid: process.Pid,
  filters: List(dynamic.Dynamic),
) -> atom.Atom
pub fn set_loopback(pid: process.Pid, value: Bool) -> atom.Atom
pub fn start_link() -> #(atom.Atom, process.Pid)
pub fn stop(pid: process.Pid) -> atom.Atom
Search Document